@@ -492,6 +492,8 @@ void MainWindow::runscript(QString command)
     SetOpacity("MediaPlayerAppletPrevious.png", opasity);
     SetOpacity("MediaPlayerAppletStopPlay.png", opasity);
     SetOpacity("OviCenter.png", opasity);
+    progress.setValue(82);
+    progress.setValue(84);
     SetOpacity("OviLeft.png", opasity);
     SetOpacity("OviRight.png", opasity);
     SetOpacity("RSSAppletHead.png", opasity);
@@ -501,22 +503,26 @@ void MainWindow::runscript(QString command)
     SetOpacity("wmRightButton.png", opasity_top);
     SetOpacity("wmButtonRightHalf.png", opasity_top);
     SetOpacity("wmButtonLeftHalf.png", opasity_top);
-    progress.setValue(82);
-    progress.setValue(84);
     progress.setValue(86);
     progress.setValue(88);
 
     if ( ui->checkBoxActivate->checkState() == Qt::Unchecked ) {
 
         progress.setLabelText(tr("Restarting services..."));
-        QMaemo5InformationBox::information(this, tr("Restarting services, your screen will blink! Rebooting the device is recommended to reload all new values."));
+        QMaemo5InformationBox::information(this, tr("Restarting services, your screen will blink! Rebooting the device is recommended to reload all new values."), QMaemo5InformationBox::DefaultTimeout);
         system("run-standalone.sh /usr/sbin/dsmetool -k /usr/bin/hildon-home");
-        system("sleep 2");
-        system("run-standalone.sh /usr/sbin/dsmetool -t /usr/bin/hildon-home");
-        system("sleep 2 && killall hildon-status-menu");
-        system("sleep 2 && killall systemui");
+        sleep(2);
+        system("killall hildon-status-menu");
+        sleep(2);
+        system("killall osso-abook-home-applet");
+        sleep(2);
+        system("killall systemui");
         progress.setValue(99);
-        system("sleep 2 && killall hildon-desktop");
+        sleep(2);
+        system("run-standalone.sh /usr/sbin/dsmetool -t /usr/bin/hildon-home");
+        sleep(4);
+        system("killall hildon-desktop");
+        sleep(2);
         system("killall theme-customizer");
 
     } else {
@@ -524,7 +530,7 @@ void MainWindow::runscript(QString command)
     system("run-standalone.sh dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:'Rebooting in 5 seconds, fasten your seatbelts!'");
     system("/sbin/launchcustomizer rebootnow");
     progress.setValue(99);
-    progress.cancel();
+ //   progress.cancel();
     // oldfonts();
 
 }
@@ -749,7 +755,7 @@ void MainWindow::on_about_triggered()
     msgBox.setWindowTitle(tr("About Theme Customizer"));
     msgBox.setText("Author: D-Iivil - Licence: Freeware & open source");
     msgBox.setTextFormat(Qt::RichText);
-    msgBox.setInformativeText("<html>Version: 0.9-35<br /><a href=\"https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=ricky%40hevikaraoke%2efi&lc=FI&item_name=Here%27s%20some%20money%20for%20beer%2e&no_note=0&currency_code=EUR&bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHostedGuest\">Be a nice guy and <b>donate some money for beer</b> to author</a></html>");
+    msgBox.setInformativeText("<html>Version: 0.9-36<br /><a href=\"https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=ricky%40hevikaraoke%2efi&lc=FI&item_name=Here%27s%20some%20money%20for%20beer%2e&no_note=0&currency_code=EUR&bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHostedGuest\">Be a nice guy and <b>donate some money for beer</b> to author</a></html>");
     msgBox.setStandardButtons(QMessageBox::Ok);
     msgBox.setDefaultButton(QMessageBox::Ok);
     msgBox.button(msgBox.Ok)->setText(tr("Ok, thanks."));
@@ -959,14 +965,22 @@ void MainWindow::on_actionRestore_theme_files_triggered()
 
 void MainWindow::process2Finished2(int)
 {
-    system("run-standalone.sh dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteDialog string:'Restarting services, your screen will blink! After all is done, rebooting the device is recommended to reload all new values' uint32:0 string:'OK'");
-    system("run-standalone.sh dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:'Restarting hildon-home...'");
+ //   system("run-standalone.sh dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteDialog string:'Restarting services, your screen will blink! After all is done, rebooting the device is recommended to reload all new values' uint32:0 string:'OK'");
+ //   system("run-standalone.sh dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:'Restarting hildon-home...'");
+    QMaemo5InformationBox::information(this, tr("Restarting services, your screen will blink! Rebooting the device is recommended to reload all new values."), QMaemo5InformationBox::DefaultTimeout);
     system("run-standalone.sh /usr/sbin/dsmetool -k /usr/bin/hildon-home");
-    system("sleep 2");
+    sleep(2);
+    system("killall hildon-status-menu");
+    sleep(2);
+    system("killall osso-abook-home-applet");
+    sleep(2);
+    system("killall systemui");
+    progress.setValue(99);
+    sleep(2);
     system("run-standalone.sh /usr/sbin/dsmetool -t /usr/bin/hildon-home");
-    system("sleep 2 && killall hildon-status-menu");
-    system("sleep 2 && killall systemui");
-    system("sleep 2 && killall hildon-desktop");
+    sleep(4);
+    system("killall hildon-desktop");
+    sleep(2);
     system("killall theme-customizer");
 }
 
